Coverage for src/beautyspot/_version.py: 0%

1# file generated by setuptools-scm

2# don't change, don't track in version control

3

4 __all__ = [

5 "__version__",

6 "__version_tuple__",

7 "version",

8 "version_tuple",

9 "__commit_id__",

10 "commit_id",

11]

12

13 TYPE_CHECKING = False

14 if TYPE_CHECKING:

15 from typing import Tuple

16 from typing import Union

17

18 VERSION_TUPLE = Tuple[Union[int, str], ...]

19 COMMIT_ID = Union[str, None]

20 else:

21 VERSION_TUPLE = object

22 COMMIT_ID = object

23

24 version: str

25 __version__: str

26 __version_tuple__: VERSION_TUPLE

27 version_tuple: VERSION_TUPLE

28 commit_id: COMMIT_ID

29 __commit_id__: COMMIT_ID

30

31 __version__ = version = '2.7.7'

32 __version_tuple__ = version_tuple = (2, 7, 7)

33

34 __commit_id__ = commit_id = None